# DSL translation

## Introduction

This Python package provides the function `dsl_translation` that translated natural language commands
into executable code.

The translations are made via a dedicated Web service.
Here is the corresponding interactive interface: https://antononcube.shinyapps.io/DSL-evaluations .

------

## Usage examples



------

## References

